# frozen_string_literal: true

module GooglePerspective
  class CommentAnalyzer
    attr_accessor :text, :client, :score

    def initialize(text:, score: 0.5)
      @client = Client.new
      @text = text
      @score = score
    end

    def valid?
      result_score <= score
    end

    def result_score
      result_scores.min
    end

    def result_scores
      @result_scores ||= response['attributeScores'].map do |_model, model_score|
        model_score.dig('summaryScore', 'value')
      end
    end

    def response
      @response ||= client.post(body)
    end

    def body
      {
        comment: {
          text: text,
          type: 'PLAIN_TEXT'
        },
        requestedAttributes: {
          TOXICITY: {},
          SEVERE_TOXICITY: {}
        }
      }
    end
  end
end
